16.66. cdist-type__install_config(7) — cdist 6.9.8 documentation

# 16.66. cdist-type__install_config(7)

## 16.66.1. NAME

cdist-type__install_config - run cdist config as part of the installation

## 16.66.2. DESCRIPTION

This cdist type allows you to run cdist config as part of the installation. It does this by using a custom __remote_{copy,exec} prefix which runs cdist config against the /target chroot on the remote host.

## 16.66.3. REQUIRED PARAMETERS

None

## 16.66.4. OPTIONAL PARAMETERS

chroot

  where to chroot before running grub-install. Defaults to /target.

## 16.66.5. EXAMPLES

    __install_config

    __install_config --chroot /mnt/somewhere

## 16.66.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.66.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.